Class: Aws::Shield::Types::Limit
- Inherits:
-
Struct
- Object
- Struct
- Aws::Shield::Types::Limit
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-shield/types.rb
Overview
Specifies how many protections of a given type you can create.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max ⇒ Integer
The maximum number of protections that can be created for the specified
Type. -
#type ⇒ String
The type of protection.
Instance Attribute Details
#max ⇒ Integer
The maximum number of protections that can be created for the specified Type.
1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-shield/types.rb', line 1159 class Limit < Struct.new( :type, :max) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of protection.
1159 1160 1161 1162 1163 1164 |
# File 'lib/aws-sdk-shield/types.rb', line 1159 class Limit < Struct.new( :type, :max) SENSITIVE = [] include Aws::Structure end |