Method: Aws::Shield::Types::Subscription#auto_renew

Defined in:
lib/aws-sdk-shield/types.rb

#auto_renewString

If ENABLED, the subscription will be automatically renewed at the end of the existing subscription period.

When you initally create a subscription, AutoRenew is set to ENABLED. You can change this by submitting an UpdateSubscription request. If the UpdateSubscription request does not included a value for AutoRenew, the existing value for AutoRenew remains unchanged.

Returns:

  • (String)


1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-shield/types.rb', line 1931

class Subscription < Struct.new(
  :start_time,
  :end_time,
  :time_commitment_in_seconds,
  :auto_renew,
  :limits,
  :proactive_engagement_status,
  :subscription_limits,
  :subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end